import "reflect-metadata";
import {setupTestingConnections, closeConnections, reloadDatabases} from "../../utils/test-utils";
import {Connection} from "../../../src/connection/Connection";
import {User} from "./entity/User";
import {expect} from "chai";
import {AccessToken} from "./entity/AccessToken";

describe("github issues > #56 relationships only work when both primary keys have the same name", () => {

    let connections: Connection[];
    before(async () => connections = await setupTestingConnections({
        entities: [__dirname + "/entity/*{.js,.ts}"],
        schemaCreate: true,
        dropSchemaOnConnection: true,
    }));
    beforeEach(() => reloadDatabases(connections));
    after(() => closeConnections(connections));

    it("should persist successfully and return persisted entity", () => Promise.all(connections.map(async connection => {

        const token = new AccessToken();
        token.access_token = "12345";

        const user = new User();
        user.email = "mwelnick@test.com";
        user.access_token = token;

        return connection.getRepository(AccessToken).persist(token).then(token => {
            return connection.getRepository(User).persist(user);
        }).then (user => {
            expect(user).not.to.be.empty;
            user.should.be.eql({
                id: 1,
                email: "mwelnick@test.com",
                access_token: {
                    access_token: "12345"
                }
            });
        });

    })));

});